3 ms·
Thanks, I run it with --nomigrations so it's not the migrations. Reusing db shaves about 2 seconds (I'm down to ~9 seconds when running a single test and specif
by cocoflunchy 4y ago
Thanks, I run it with --nomigrations so it's not the migrations. Reusing db shaves about 2 seconds (I'm down to ~9 seconds when running a single test and specifying the full path)